@@ -2,27 +2,42 @@ from django import forms
 from avocado.models import DataContext, DataView
 
 
-class DataContextForm(forms.ModelForm):
+class ContextForm(forms.ModelForm):
     def __init__(self, request, *args, **kwargs):
         self.request = request
-        super(DataContextForm, self).__init__(*args, **kwargs)
+        self.count_needs_update = kwargs.pop('force_count', None)
+        super(ContextForm, self).__init__(*args, **kwargs)
 
     def clean_json(self):
         json = self.cleaned_data.get('json')
-        if not self.instance or self.instance.count is None or self.instance.json != json:
-            self.count_needs_update = True
-        else:
-            self.count_needs_update = False
+
+        if self.count_needs_update is None and self.instance:
+            existing = self.instance.json
+            if existing or json and existing != json or json and self.instance.count is None:
+                self.count_needs_update = True
+            else:
+                self.count_needs_update = False
         return json
 
-    def save(self, commit=True, archive=True):
-        instance = super(DataContextForm, self).save(commit=False)
+    def save(self, commit=True, archive=False):
+        instance = super(ContextForm, self).save(commit=False)
         request = self.request
+
         if hasattr(request, 'user') and request.user.is_authenticated():
             instance.user = request.user
         else:
             instance.session_key = request.session.session_key
 
+        # Only recalculated count if conditions exist. This is to
+        # prevent re-counting the entire dataset. An alternative
+        # solution may be desirable such as pre-computing and
+        # caching the count ahead of time.
+        if self.count_needs_update:
+            instance.count = instance.apply().distinct().count()
+            self.count_needs_update = False
+        else:
+            instance.count = None
+
         if commit:
             instance.save()
             if archive:
@@ -35,22 +50,27 @@ class DataContextForm(forms.ModelForm):
         fields = ('name', 'description', 'keywords', 'json', 'session')
 
 
-class DataViewForm(forms.ModelForm):
+class ViewForm(forms.ModelForm):
     def __init__(self, request, *args, **kwargs):
         self.request = request
-        super(DataViewForm, self).__init__(*args, **kwargs)
+        self.count_needs_update = kwargs.pop('force_count', None)
+        super(ViewForm, self).__init__(*args, **kwargs)
 
     def clean_json(self):
         json = self.cleaned_data.get('json')
-        if not self.instance or self.instance.count is None or self.instance.json != json:
-            self.count_needs_update = True
-        else:
-            self.count_needs_update = False
+
+        if self.count_needs_update is None:
+            existing = self.instance.json
+            if existing or json and existing != json or json and self.instance.count is None:
+                self.count_needs_update = True
+            else:
+                self.count_needs_update = False
         return json
 
-    def save(self, commit=True, archive=True):
-        instance = super(DataViewForm, self).save(commit=False)
+    def save(self, commit=True, archive=False):
+        instance = super(ViewForm, self).save(commit=False)
         request = self.request
+
         if hasattr(request, 'user') and request.user.is_authenticated():
             instance.user = request.user
         else:
