@@ -6,7 +6,7 @@ import serrano
 from serrano.tokens import token_generator
 from .base import BaseResource
 
-API_VERSION = int('{major}{minor}'.format(**serrano.__version_info__))
+API_VERSION = '{major}.{minor}.{micro}'.format(**serrano.__version_info__)
 
 class Root(BaseResource):
     # Override to allow a POST to not be checked for authorization since
@@ -24,31 +24,24 @@ class Root(BaseResource):
             'version': API_VERSION,
             '_links': {
                 'self': {
-                    'rel': 'self',
                     'href': uri(reverse('serrano:root')),
                 },
                 'fields': {
-                    'rel': 'datafields',
-                    'href': uri(reverse('serrano:datafields')),
+                    'href': uri(reverse('serrano:fields')),
                 },
                 'concepts': {
-                    'rel': 'dataconcepts',
-                    'href': uri(reverse('serrano:dataconcepts')),
+                    'href': uri(reverse('serrano:concepts')),
                 },
                 'contexts': {
-                    'rel': 'datacontexts',
                     'href': uri(reverse('serrano:contexts:active')),
                 },
                 'views': {
-                    'rel': 'dataviews',
                     'href': uri(reverse('serrano:views:active')),
                 },
                 'preview': {
-                    'rel': 'data',
                     'href': uri(reverse('serrano:data:preview')),
                 },
                 'exporter': {
-                    'rel': 'data',
                     'href': uri(reverse('serrano:data:exporter')),
                 }
             }
