@@ -1,51 +1,48 @@
-# DataField core fields and properties
-
-DataCategory = {
-    'fields': [':pk', 'name', 'order', 'parent'],
-    'related': {
-        'parent': {
-            'fields': [':pk', 'name', 'order'],
-        }
-    },
+Category = {
+    'fields': [':pk', 'name', 'order', 'parent_id'],
     'allow_missing': True,
 }
 
-DataField = {
+BriefField = {
+    'fields': [':pk', 'name', 'description'],
+    'allow_missing': True,
+}
+
+Field = {
     'fields': [
         ':pk', 'name', 'plural_name', 'description', 'keywords',
-        'category', 'app_name', 'model_name', 'field_name',
+        'app_name', 'model_name', 'field_name',
         'modified', 'published', 'archived', 'operators',
         'simple_type', 'internal_type', 'data_modified', 'enumerable',
         'searchable', 'unit', 'plural_unit', 'nullable'
     ],
-    'key_map': {
+    'aliases': {
         'plural_name': 'get_plural_name',
         'plural_unit': 'get_plural_unit',
     },
-    'related': {
-        'category': DataCategory,
-    },
     'allow_missing': True,
 }
 
-DataConcept = {
+BriefConcept = {
+    'fields': [':pk', 'name', 'description'],
+    'allow_missing': True,
+}
+
+Concept = {
     'fields': [
         ':pk', 'name', 'plural_name', 'description', 'keywords',
-        'category', 'order', 'modified', 'published', 'archived',
+        'category_id', 'order', 'modified', 'published', 'archived',
         'formatter_name', 'queryview', 'sortable'
     ],
-    'key_map': {
+    'aliases': {
         'plural_name': 'get_plural_name',
     },
-    'related': {
-        'category': DataCategory,
-    },
     'allow_missing': True,
 }
 
-DataConceptField = {
+ConceptField = {
     'fields': ['alt_name', 'alt_plural_name'],
-    'key_map': {
+    'aliases': {
         'alt_name': 'name',
         'alt_plural_name': 'get_plural_name',
     },
@@ -53,14 +50,13 @@ DataConceptField = {
 }
 
 
-DataContext = {
-    'fields': [':pk', ':local', 'language'],
+Context = {
     'exclude': ['user', 'session_key'],
     'allow_missing': True,
 }
 
 
-DataView = {
+View = {
     'exclude': ['user', 'session_key'],
     'allow_missing': True,
 }
